@@ -1,3 +1,3 @@
 from conda_package_handling import cli
 
-cli.cli()
+cli.main(args=None)
