@@ -19,10 +19,10 @@ from .interface import AbstractBaseFormat
 from .streaming import _extract
 
 CONDA_PACKAGE_FORMAT_VERSION = 2
-DEFAULT_COMPRESSION_TUPLE = (".tar.zst", "zstd", "zstd:compression-level=22")
+DEFAULT_COMPRESSION_TUPLE = (".tar.zst", "zstd", "zstd:compression-level=19")
 
 # increase to reduce speed and increase compression (22 = conda's default)
-ZSTD_COMPRESS_LEVEL = 22
+ZSTD_COMPRESS_LEVEL = 19
 # increase to reduce compression (slightly) and increase speed
 ZSTD_COMPRESS_THREADS = 1
 
@@ -85,10 +85,24 @@ class CondaFormat_v2(AbstractBaseFormat):
                     threads=ZSTD_COMPRESS_THREADS,
                 )
 
+        class NullWriter:
+            """
+            zstd uses less memory on extract if size is known.
+            """
+
+            def __init__(self):
+                self.size = 0
+
+            def write(self, bytes):
+                self.size += len(bytes)
+                return len(bytes)
+
+            def tell(self):
+                return self.size
+
         with ZipFile(conda_pkg_fn, "w", compression=ZIP_STORED) as conda_file, utils.tmp_chdir(
             prefix
         ):
-
             pkg_metadata = {"conda_pkg_format_version": CONDA_PACKAGE_FORMAT_VERSION}
             conda_file.writestr("metadata.json", json.dumps(pkg_metadata))
 
@@ -98,10 +112,20 @@ class CondaFormat_v2(AbstractBaseFormat):
             )
 
             # put the info last, for parity with updated transmute.
+            compress = compressor()
             for component, files in components_files:
-                compress = compressor()
+                # If size is known, the decompressor may be able to allocate less memory.
+                # The compressor will error if size is not correct.
+                with tarfile.TarFile(fileobj=NullWriter(), mode="w") as sizer:  # type: ignore
+                    for file in files:
+                        sizer.add(file, filter=utils.anonymize_tarinfo)
+                size = sizer.fileobj.size  # type: ignore
+
                 with conda_file.open(component, "w") as component_file:
-                    component_stream = compress.stream_writer(component_file, closefd=False)
+                    # only one stream_writer() per compressor() must be in use at a time
+                    component_stream = compress.stream_writer(
+                        component_file, size=size, closefd=False
+                    )
                     component_tar = tarfile.TarFile(fileobj=component_stream, mode="w")
 
                     for file in files:
